# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/search.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/search.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/speechsense/v1/search.proto\x12\x1byandex.cloud.speechsense.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x86\x04\n\x06\x46ilter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12@\n\tany_match\x18\x02 \x01(\x0b\x32+.yandex.cloud.speechsense.v1.AnyMatchFilterH\x00\x12@\n\tint_range\x18\x03 \x01(\x0b\x32+.yandex.cloud.speechsense.v1.IntRangeFilterH\x00\x12\x46\n\x0c\x64ouble_range\x18\x04 \x01(\x0b\x32..yandex.cloud.speechsense.v1.DoubleRangeFilterH\x00\x12\x42\n\ndate_range\x18\x05 \x01(\x0b\x32,.yandex.cloud.speechsense.v1.DateRangeFilterH\x00\x12J\n\x0e\x64uration_range\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.speechsense.v1.DurationRangeFilterH\x00\x12\x43\n\rboolean_match\x18\t \x01(\x0b\x32*.yandex.cloud.speechsense.v1.BooleanFilterH\x00\x12\x0f\n\x07inverse\x18\x07 \x01(\x08\x12\x33\n\x0e\x63hannel_number\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\n\x06\x66ilter\"[\n\x05Query\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0f\n\x07inverse\x18\x02 \x01(\x08\x12\x33\n\x0e\x63hannel_number\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\" \n\x0e\x41nyMatchFilter\x12\x0e\n\x06values\x18\x01 \x03(\t\"?\n\x0f\x42oundsInclusive\x12\x16\n\x0e\x66rom_inclusive\x18\x01 \x01(\x08\x12\x14\n\x0cto_inclusive\x18\x02 \x01(\x08\"\xb8\x01\n\x0eIntRangeFilter\x12/\n\nfrom_value\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08to_value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n\x10\x62ounds_inclusive\x18\x03 \x01(\x0b\x32,.yandex.cloud.speechsense.v1.BoundsInclusive\"\xbd\x01\n\x11\x44oubleRangeFilter\x12\x30\n\nfrom_value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12.\n\x08to_value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x46\n\x10\x62ounds_inclusive\x18\x03 \x01(\x0b\x32,.yandex.cloud.speechsense.v1.BoundsInclusive\"\xb7\x01\n\x0f\x44\x61teRangeFilter\x12.\n\nfrom_value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08to_value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x46\n\x10\x62ounds_inclusive\x18\x03 \x01(\x0b\x32,.yandex.cloud.speechsense.v1.BoundsInclusive\"\xb9\x01\n\x13\x44urationRangeFilter\x12-\n\nfrom_value\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08to_value\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x46\n\x10\x62ounds_inclusive\x18\x03 \x01(\x0b\x32,.yandex.cloud.speechsense.v1.BoundsInclusive\"\x1e\n\rBooleanFilter\x12\r\n\x05value\x18\x01 \x01(\x08\"B\n\x08SortData\x12\x36\n\x06\x66ields\x18\x01 \x03(\x0b\x32&.yandex.cloud.speechsense.v1.SortField\"c\n\tSortField\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x35\n\x05order\x18\x02 \x01(\x0e\x32&.yandex.cloud.speechsense.v1.SortOrder\x12\x10\n\x08position\x18\x03 \x01(\x03*P\n\tSortOrder\x12\x1a\n\x16SORT_ORDER_UNSPECIFIED\x10\x00\x12\x12\n\x0eSORT_ORDER_ASC\x10\x01\x12\x13\n\x0fSORT_ORDER_DESC\x10\x02\x42{\n\x1fyandex.cloud.api.speechsense.v1B\x0bSearchProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.search_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\013SearchProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_SORTORDER']._serialized_start=1837
  _globals['_SORTORDER']._serialized_end=1917
  _globals['_FILTER']._serialized_start=171
  _globals['_FILTER']._serialized_end=689
  _globals['_QUERY']._serialized_start=691
  _globals['_QUERY']._serialized_end=782
  _globals['_ANYMATCHFILTER']._serialized_start=784
  _globals['_ANYMATCHFILTER']._serialized_end=816
  _globals['_BOUNDSINCLUSIVE']._serialized_start=818
  _globals['_BOUNDSINCLUSIVE']._serialized_end=881
  _globals['_INTRANGEFILTER']._serialized_start=884
  _globals['_INTRANGEFILTER']._serialized_end=1068
  _globals['_DOUBLERANGEFILTER']._serialized_start=1071
  _globals['_DOUBLERANGEFILTER']._serialized_end=1260
  _globals['_DATERANGEFILTER']._serialized_start=1263
  _globals['_DATERANGEFILTER']._serialized_end=1446
  _globals['_DURATIONRANGEFILTER']._serialized_start=1449
  _globals['_DURATIONRANGEFILTER']._serialized_end=1634
  _globals['_BOOLEANFILTER']._serialized_start=1636
  _globals['_BOOLEANFILTER']._serialized_end=1666
  _globals['_SORTDATA']._serialized_start=1668
  _globals['_SORTDATA']._serialized_end=1734
  _globals['_SORTFIELD']._serialized_start=1736
  _globals['_SORTFIELD']._serialized_end=1835
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Reference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Reference._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Reference._Type.ValueType  # 0
        MANAGED_BY: Reference._Type.ValueType  # 1
        USED_BY: Reference._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Reference.Type.ValueType  # 0
    MANAGED_BY: Reference.Type.ValueType  # 1
    USED_BY: Reference.Type.ValueType  # 2

    REFERRER_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    type: global___Reference.Type.ValueType
    @property
    def referrer(self) -> global___Referrer: ...
    def __init__(
        self,
        *,
        referrer: global___Referrer | None = ...,
        type: global___Reference.Type.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["referrer", b"referrer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["referrer", b"referrer", "type", b"type"]) -> None: ...

global___Reference = Reference

@typing.final
class Referrer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    type: builtins.str
    """* `type = compute.instance, id = <instance id>`
    * `type = compute.instanceGroup, id = <instanceGroup id>`
    * `type = loadbalancer.networkLoadBalancer, id = <networkLoadBalancer id>`
    * `type = managed-kubernetes.cluster, id = <cluster id>`
    * `type = managed-mysql.cluster, id = <cluster id>`
    """
    id: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "type", b"type"]) -> None: ...

global___Referrer = Referrer



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_pb2
import yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class AsymmetricEncryptionKeyServiceStub:
    """Set of methods for managing asymmetric KMS keys."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.CreateAsymmetricEncryptionKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """control plane
    Creates an asymmetric KMS key in the specified folder.
    """

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.GetAsymmetricEncryptionKeyRequest,
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_pb2.AsymmetricEncryptionKey,
    ]
    """Returns the specified asymmetric KMS key.

     To get the list of available asymmetric KMS keys, make a [SymmetricKeyService.List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeysRequest,
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeysResponse,
    ]
    """Returns the list of asymmetric KMS keys in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.UpdateAsymmetricEncryptionKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified asymmetric KMS key."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.DeleteAsymmetricEncryptionKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified asymmetric KMS key. This action also automatically schedules
    the destruction of all of the key's versions in 72 hours.

    The key and its versions appear absent in [AsymmetricEncryptionKeyService.Get] and [AsymmetricEncryptionKeyService.List]
    requests, but can be restored within 72 hours with a request to tech support.
    """

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeyOperationsRequest,
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeyOperationsResponse,
    ]
    """Lists operations for the specified asymmetric KMS key."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified key."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the key."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified key."""

class AsymmetricEncryptionKeyServiceAsyncStub:
    """Set of methods for managing asymmetric KMS keys."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.CreateAsymmetricEncryptionKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """control plane
    Creates an asymmetric KMS key in the specified folder.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.GetAsymmetricEncryptionKeyRequest,
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_pb2.AsymmetricEncryptionKey,
    ]
    """Returns the specified asymmetric KMS key.

     To get the list of available asymmetric KMS keys, make a [SymmetricKeyService.List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeysRequest,
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeysResponse,
    ]
    """Returns the list of asymmetric KMS keys in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.UpdateAsymmetricEncryptionKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified asymmetric KMS key."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.DeleteAsymmetricEncryptionKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified asymmetric KMS key. This action also automatically schedules
    the destruction of all of the key's versions in 72 hours.

    The key and its versions appear absent in [AsymmetricEncryptionKeyService.Get] and [AsymmetricEncryptionKeyService.List]
    requests, but can be restored within 72 hours with a request to tech support.
    """

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeyOperationsRequest,
        yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeyOperationsResponse,
    ]
    """Lists operations for the specified asymmetric KMS key."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists existing access bindings for the specified key."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the key."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified key."""

class AsymmetricEncryptionKeyServiceServicer(metaclass=abc.ABCMeta):
    """Set of methods for managing asymmetric KMS keys."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.CreateAsymmetricEncryptionKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """control plane
        Creates an asymmetric KMS key in the specified folder.
        """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.GetAsymmetricEncryptionKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_pb2.AsymmetricEncryptionKey, collections.abc.Awaitable[yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_pb2.AsymmetricEncryptionKey]]:
        """Returns the specified asymmetric KMS key.

         To get the list of available asymmetric KMS keys, make a [SymmetricKeyService.List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeysRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeysResponse, collections.abc.Awaitable[yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeysResponse]]:
        """Returns the list of asymmetric KMS keys in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.UpdateAsymmetricEncryptionKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified asymmetric KMS key."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.DeleteAsymmetricEncryptionKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified asymmetric KMS key. This action also automatically schedules
        the destruction of all of the key's versions in 72 hours.

        The key and its versions appear absent in [AsymmetricEncryptionKeyService.Get] and [AsymmetricEncryptionKeyService.List]
        requests, but can be restored within 72 hours with a request to tech support.
        """

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeyOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeyOperationsResponse, collections.abc.Awaitable[yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2.ListAsymmetricEncryptionKeyOperationsResponse]]:
        """Lists operations for the specified asymmetric KMS key."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists existing access bindings for the specified key."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the key."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified key."""

def add_AsymmetricEncryptionKeyServiceServicer_to_server(servicer: AsymmetricEncryptionKeyServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.compute.v1.instance_service_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateComputeInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    LABELS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    RESOURCES_SPEC_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    BOOT_DISK_SPEC_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACE_SPECS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PLATFORM_ID_FIELD_NUMBER: builtins.int
    zone_id: builtins.str
    """ID of the availability zone where the instance resides.
    To get a list of available zones, use the [yandex.cloud.compute.v1.ZoneService.List] request
    """
    service_account_id: builtins.str
    """ID of the service account to use for [authentication inside the instance](/docs/compute/operations/vm-connect/auth-inside-vm).
    To get the service account ID, use a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    """
    platform_id: builtins.str
    """ID of the [Compute VM platform](/docs/compute/concepts/vm-platforms) on which the agent will be created.
    Default value: "standard-v2"
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def resources_spec(self) -> yandex.cloud.compute.v1.instance_service_pb2.ResourcesSpec:
        """Computing resources of the instance, such as the amount of memory and number of cores.
        To get a list of available values, see [Levels of core performance](/docs/compute/concepts/performance-levels).
        """

    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """The metadata `key:value` pairs that will be assigned to this instance. This includes custom metadata and predefined keys.
        The total size of all keys and values must be less than 512 KB.

        Values are free-form strings, and only have meaning as interpreted by the programs which configure the instance.
        The values must be 256 KB or less.

        For example, you may use the metadata in order to provide your public SSH key to the instance.
        For more information, see [Metadata](/docs/compute/concepts/vm-metadata).
        """

    @property
    def boot_disk_spec(self) -> yandex.cloud.compute.v1.instance_service_pb2.AttachedDiskSpec:
        """Boot disk to attach to the instance."""

    @property
    def network_interface_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.instance_service_pb2.NetworkInterfaceSpec]:
        """Network configuration for the instance. Specifies how the network interface is configured
        to interact with other services on the internal network and on the internet.
        Currently only one network interface is supported per instance.
        """

    def __init__(
        self,
        *,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zone_id: builtins.str = ...,
        resources_spec: yandex.cloud.compute.v1.instance_service_pb2.ResourcesSpec | None = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        boot_disk_spec: yandex.cloud.compute.v1.instance_service_pb2.AttachedDiskSpec | None = ...,
        network_interface_specs: collections.abc.Iterable[yandex.cloud.compute.v1.instance_service_pb2.NetworkInterfaceSpec] | None = ...,
        service_account_id: builtins.str = ...,
        platform_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["boot_disk_spec", b"boot_disk_spec", "resources_spec", b"resources_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["boot_disk_spec", b"boot_disk_spec", "labels", b"labels", "metadata", b"metadata", "network_interface_specs", b"network_interface_specs", "platform_id", b"platform_id", "resources_spec", b"resources_spec", "service_account_id", b"service_account_id", "zone_id", b"zone_id"]) -> None: ...

global___CreateComputeInstance = CreateComputeInstance



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Points(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUIZ_FIELD_NUMBER: builtins.int
    @property
    def quiz(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Quiz]: ...
    def __init__(
        self,
        *,
        quiz: collections.abc.Iterable[global___Quiz] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["quiz", b"quiz"]) -> None: ...

global___Points = Points

@typing.final
class Quiz(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    request: builtins.str
    id: builtins.str
    @property
    def response(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        request: builtins.str = ...,
        response: google.protobuf.wrappers_pb2.StringValue | None = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["response", b"response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "request", b"request", "response", b"response"]) -> None: ...

global___Quiz = Quiz



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.vision.v1.primitives_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TextAnnotation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGES_FIELD_NUMBER: builtins.int
    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Page]:
        """Pages of the recognized file.

        For JPEG and PNG files contains only 1 page.
        """

    def __init__(
        self,
        *,
        pages: collections.abc.Iterable[global___Page] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["pages", b"pages"]) -> None: ...

global___TextAnnotation = TextAnnotation

@typing.final
class Page(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    BLOCKS_FIELD_NUMBER: builtins.int
    ENTITIES_FIELD_NUMBER: builtins.int
    width: builtins.int
    """Page width in pixels."""
    height: builtins.int
    """Page height in pixels."""
    @property
    def blocks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Block]:
        """Recognized text blocks in this page."""

    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Entity]:
        """Recognized entities"""

    def __init__(
        self,
        *,
        width: builtins.int = ...,
        height: builtins.int = ...,
        blocks: collections.abc.Iterable[global___Block] | None = ...,
        entities: collections.abc.Iterable[global___Entity] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["blocks", b"blocks", "entities", b"entities", "height", b"height", "width", b"width"]) -> None: ...

global___Page = Page

@typing.final
class Entity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Entity name"""
    text: builtins.str
    """Recognized entity text"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "text", b"text"]) -> None: ...

global___Entity = Entity

@typing.final
class Block(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOUNDING_BOX_FIELD_NUMBER: builtins.int
    LINES_FIELD_NUMBER: builtins.int
    @property
    def bounding_box(self) -> yandex.cloud.ai.vision.v1.primitives_pb2.Polygon:
        """Area on the page where the text block is located."""

    @property
    def lines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Line]:
        """Recognized lines in this block."""

    def __init__(
        self,
        *,
        bounding_box: yandex.cloud.ai.vision.v1.primitives_pb2.Polygon | None = ...,
        lines: collections.abc.Iterable[global___Line] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounding_box", b"bounding_box"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounding_box", b"bounding_box", "lines", b"lines"]) -> None: ...

global___Block = Block

@typing.final
class Line(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOUNDING_BOX_FIELD_NUMBER: builtins.int
    WORDS_FIELD_NUMBER: builtins.int
    CONFIDENCE_FIELD_NUMBER: builtins.int
    confidence: builtins.float
    """Confidence of the OCR results for the line. Range [0, 1]."""
    @property
    def bounding_box(self) -> yandex.cloud.ai.vision.v1.primitives_pb2.Polygon:
        """Area on the page where the line is located."""

    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Word]:
        """Recognized words in this line."""

    def __init__(
        self,
        *,
        bounding_box: yandex.cloud.ai.vision.v1.primitives_pb2.Polygon | None = ...,
        words: collections.abc.Iterable[global___Word] | None = ...,
        confidence: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounding_box", b"bounding_box"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounding_box", b"bounding_box", "confidence", b"confidence", "words", b"words"]) -> None: ...

global___Line = Line

@typing.final
class Word(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DetectedLanguage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LANGUAGE_CODE_FIELD_NUMBER: builtins.int
        CONFIDENCE_FIELD_NUMBER: builtins.int
        language_code: builtins.str
        """Detected language code."""
        confidence: builtins.float
        """Confidence of detected language. Range [0, 1]."""
        def __init__(
            self,
            *,
            language_code: builtins.str = ...,
            confidence: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["confidence", b"confidence", "language_code", b"language_code"]) -> None: ...

    BOUNDING_BOX_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    CONFIDENCE_FIELD_NUMBER: builtins.int
    LANGUAGES_FIELD_NUMBER: builtins.int
    ENTITY_INDEX_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Recognized word value."""
    confidence: builtins.float
    """Confidence of the OCR results for the word. Range [0, 1]."""
    entity_index: builtins.int
    """Id of recognized word in entities array"""
    @property
    def bounding_box(self) -> yandex.cloud.ai.vision.v1.primitives_pb2.Polygon:
        """Area on the page where the word is located."""

    @property
    def languages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Word.DetectedLanguage]:
        """A list of detected languages together with confidence."""

    def __init__(
        self,
        *,
        bounding_box: yandex.cloud.ai.vision.v1.primitives_pb2.Polygon | None = ...,
        text: builtins.str = ...,
        confidence: builtins.float = ...,
        languages: collections.abc.Iterable[global___Word.DetectedLanguage] | None = ...,
        entity_index: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bounding_box", b"bounding_box"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bounding_box", b"bounding_box", "confidence", b"confidence", "entity_index", b"entity_index", "languages", b"languages", "text", b"text"]) -> None: ...

global___Word = Word



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iot/devices/v1/registry_data_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iot/devices/v1/registry_data_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/iot/devices/v1/registry_data_service.proto\x12\x1byandex.cloud.iot.devices.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"z\n\x1aPublishRegistryDataRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x05topic\x18\x02 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1024\x12\x1a\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x42\x0c\x8a\xc8\x31\x08<=262144\"\x1d\n\x1bPublishRegistryDataResponse2\xd1\x01\n\x13RegistryDataService\x12\xb9\x01\n\x07Publish\x12\x37.yandex.cloud.iot.devices.v1.PublishRegistryDataRequest\x1a\x38.yandex.cloud.iot.devices.v1.PublishRegistryDataResponse\";\x82\xd3\xe4\x93\x02\x35\"0/iot-devices/v1/registries/{registry_id}/publish:\x01*Bj\n\x1fyandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devicesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iot.devices.v1.registry_data_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.iot.devices.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/devices/v1;devices'
  _globals['_PUBLISHREGISTRYDATAREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_PUBLISHREGISTRYDATAREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PUBLISHREGISTRYDATAREQUEST'].fields_by_name['topic']._loaded_options = None
  _globals['_PUBLISHREGISTRYDATAREQUEST'].fields_by_name['topic']._serialized_options = b'\350\3071\001\212\3101\006<=1024'
  _globals['_PUBLISHREGISTRYDATAREQUEST'].fields_by_name['data']._loaded_options = None
  _globals['_PUBLISHREGISTRYDATAREQUEST'].fields_by_name['data']._serialized_options = b'\212\3101\010<=262144'
  _globals['_REGISTRYDATASERVICE'].methods_by_name['Publish']._loaded_options = None
  _globals['_REGISTRYDATASERVICE'].methods_by_name['Publish']._serialized_options = b'\202\323\344\223\0025\"0/iot-devices/v1/registries/{registry_id}/publish:\001*'
  _globals['_PUBLISHREGISTRYDATAREQUEST']._serialized_start=149
  _globals['_PUBLISHREGISTRYDATAREQUEST']._serialized_end=271
  _globals['_PUBLISHREGISTRYDATARESPONSE']._serialized_start=273
  _globals['_PUBLISHREGISTRYDATARESPONSE']._serialized_end=302
  _globals['_REGISTRYDATASERVICE']._serialized_start=305
  _globals['_REGISTRYDATASERVICE']._serialized_end=514
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/user_account.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/user_account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/organizationmanager/v1/user_account.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1dyandex/cloud/validation.proto\"\xea\x01\n\x0bUserAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x66\n\x1cyandex_passport_user_account\x18\x02 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.YandexPassportUserAccountH\x00\x12Q\n\x11saml_user_account\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.organizationmanager.v1.SamlUserAccountH\x00\x42\x14\n\x0cuser_account\x12\x04\xc0\xc1\x31\x01\"A\n\x19YandexPassportUserAccount\x12\r\n\x05login\x18\x01 \x01(\t\x12\x15\n\rdefault_email\x18\x02 \x01(\t\"\xbf\x02\n\x0fSamlUserAccount\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x07name_id\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x31-256\x12X\n\nattributes\x18\x03 \x03(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.SamlUserAccount.AttributesEntry\x1a\x1a\n\tAttribute\x12\r\n\x05value\x18\x01 \x03(\t\x1aq\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12M\n\x05value\x18\x02 \x01(\x0b\x32>.yandex.cloud.organizationmanager.v1.SamlUserAccount.Attribute:\x02\x38\x01\x42\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.user_account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _globals['_USERACCOUNT'].oneofs_by_name['user_account']._loaded_options = None
  _globals['_USERACCOUNT'].oneofs_by_name['user_account']._serialized_options = b'\300\3011\001'
  _globals['_SAMLUSERACCOUNT_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_SAMLUSERACCOUNT_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_SAMLUSERACCOUNT'].fields_by_name['federation_id']._loaded_options = None
  _globals['_SAMLUSERACCOUNT'].fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SAMLUSERACCOUNT'].fields_by_name['name_id']._loaded_options = None
  _globals['_SAMLUSERACCOUNT'].fields_by_name['name_id']._serialized_options = b'\350\3071\001\212\3101\0051-256'
  _globals['_USERACCOUNT']._serialized_start=127
  _globals['_USERACCOUNT']._serialized_end=361
  _globals['_YANDEXPASSPORTUSERACCOUNT']._serialized_start=363
  _globals['_YANDEXPASSPORTUSERACCOUNT']._serialized_end=428
  _globals['_SAMLUSERACCOUNT']._serialized_start=431
  _globals['_SAMLUSERACCOUNT']._serialized_end=750
  _globals['_SAMLUSERACCOUNT_ATTRIBUTE']._serialized_start=609
  _globals['_SAMLUSERACCOUNT_ATTRIBUTE']._serialized_end=635
  _globals['_SAMLUSERACCOUNT_ATTRIBUTESENTRY']._serialized_start=637
  _globals['_SAMLUSERACCOUNT_ATTRIBUTESENTRY']._serialized_end=750
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.dataproc.manager.v1.job_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class JobServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    ListActive: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.manager.v1.job_service_pb2.ListJobsRequest,
        yandex.cloud.dataproc.manager.v1.job_service_pb2.ListJobsResponse,
    ]
    """Retrieves a list of jobs for Data Proc cluster."""

    UpdateStatus: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateJobStatusRequest,
        yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateJobStatusResponse,
    ]
    """Currently used to update Job status."""

    ListSupportActive: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.manager.v1.job_service_pb2.ListJobsRequest,
        yandex.cloud.dataproc.manager.v1.job_service_pb2.ListSupportJobsResponse,
    ]
    """Retrieves a list of support jobs for Data Proc cluster."""

    UpdateSupportStatus: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateSupportJobStatusRequest,
        yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateJobStatusResponse,
    ]
    """Currently used to update support job status."""

    SaveSupportLog: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.manager.v1.job_service_pb2.SaveSupportJobLogRequest,
        yandex.cloud.dataproc.manager.v1.job_service_pb2.SaveSupportJobLogResponse,
    ]
    """Save support job output."""

class JobServiceAsyncStub:
    ListActive: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.manager.v1.job_service_pb2.ListJobsRequest,
        yandex.cloud.dataproc.manager.v1.job_service_pb2.ListJobsResponse,
    ]
    """Retrieves a list of jobs for Data Proc cluster."""

    UpdateStatus: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateJobStatusRequest,
        yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateJobStatusResponse,
    ]
    """Currently used to update Job status."""

    ListSupportActive: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.manager.v1.job_service_pb2.ListJobsRequest,
        yandex.cloud.dataproc.manager.v1.job_service_pb2.ListSupportJobsResponse,
    ]
    """Retrieves a list of support jobs for Data Proc cluster."""

    UpdateSupportStatus: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateSupportJobStatusRequest,
        yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateJobStatusResponse,
    ]
    """Currently used to update support job status."""

    SaveSupportLog: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.manager.v1.job_service_pb2.SaveSupportJobLogRequest,
        yandex.cloud.dataproc.manager.v1.job_service_pb2.SaveSupportJobLogResponse,
    ]
    """Save support job output."""

class JobServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ListActive(
        self,
        request: yandex.cloud.dataproc.manager.v1.job_service_pb2.ListJobsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dataproc.manager.v1.job_service_pb2.ListJobsResponse, collections.abc.Awaitable[yandex.cloud.dataproc.manager.v1.job_service_pb2.ListJobsResponse]]:
        """Retrieves a list of jobs for Data Proc cluster."""

    @abc.abstractmethod
    def UpdateStatus(
        self,
        request: yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateJobStatusRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateJobStatusResponse, collections.abc.Awaitable[yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateJobStatusResponse]]:
        """Currently used to update Job status."""

    @abc.abstractmethod
    def ListSupportActive(
        self,
        request: yandex.cloud.dataproc.manager.v1.job_service_pb2.ListJobsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dataproc.manager.v1.job_service_pb2.ListSupportJobsResponse, collections.abc.Awaitable[yandex.cloud.dataproc.manager.v1.job_service_pb2.ListSupportJobsResponse]]:
        """Retrieves a list of support jobs for Data Proc cluster."""

    @abc.abstractmethod
    def UpdateSupportStatus(
        self,
        request: yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateSupportJobStatusRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateJobStatusResponse, collections.abc.Awaitable[yandex.cloud.dataproc.manager.v1.job_service_pb2.UpdateJobStatusResponse]]:
        """Currently used to update support job status."""

    @abc.abstractmethod
    def SaveSupportLog(
        self,
        request: yandex.cloud.dataproc.manager.v1.job_service_pb2.SaveSupportJobLogRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dataproc.manager.v1.job_service_pb2.SaveSupportJobLogResponse, collections.abc.Awaitable[yandex.cloud.dataproc.manager.v1.job_service_pb2.SaveSupportJobLogResponse]]:
        """Save support job output."""

def add_JobServiceServicer_to_server(servicer: JobServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/workload/oidc/federation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/workload/oidc/federation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/iam/v1/workload/oidc/federation.proto\x12!yandex.cloud.iam.v1.workload.oidc\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbe\x02\n\nFederation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x11\n\taudiences\x18\x06 \x03(\t\x12\x0e\n\x06issuer\x18\x07 \x01(\t\x12\x10\n\x08jwks_url\x18\x08 \x01(\t\x12I\n\x06labels\x18\t \x03(\x0b\x32\x39.yandex.cloud.iam.v1.workload.oidc.Federation.LabelsEntry\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42s\n%yandex.cloud.api.iam.v1.workload.oidcZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/workload/oidc;oidcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.workload.oidc.federation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.iam.v1.workload.oidcZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/workload/oidc;oidc'
  _globals['_FEDERATION_LABELSENTRY']._loaded_options = None
  _globals['_FEDERATION_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_FEDERATION']._serialized_start=123
  _globals['_FEDERATION']._serialized_end=441
  _globals['_FEDERATION_LABELSENTRY']._serialized_start=396
  _globals['_FEDERATION_LABELSENTRY']._serialized_end=441
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Version(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DEPRECATED_FIELD_NUMBER: builtins.int
    UPDATABLE_TO_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the version."""
    name: builtins.str
    """Name of the version."""
    deprecated: builtins.bool
    """Whether version is deprecated."""
    @property
    def updatable_to(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of versions that can be updated from current."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        deprecated: builtins.bool = ...,
        updatable_to: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deprecated", b"deprecated", "id", b"id", "name", b"name", "updatable_to", b"updatable_to"]) -> None: ...

global___Version = Version



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.greenplum.v1.pxf_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class PXFDatasourceServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.ListPXFDatasourcesRequest,
        yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.ListPXFDatasourcesResponse,
    ]
    """List all PXF datasources"""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.CreatePXFDatasourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates PXF datasource"""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.UpdatePXFDatasourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update PXF datasource"""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.DeletePXFDatasourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete PXF datasource"""

class PXFDatasourceServiceAsyncStub:
    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.ListPXFDatasourcesRequest,
        yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.ListPXFDatasourcesResponse,
    ]
    """List all PXF datasources"""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.CreatePXFDatasourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates PXF datasource"""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.UpdatePXFDatasourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update PXF datasource"""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.DeletePXFDatasourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete PXF datasource"""

class PXFDatasourceServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.ListPXFDatasourcesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.ListPXFDatasourcesResponse, collections.abc.Awaitable[yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.ListPXFDatasourcesResponse]]:
        """List all PXF datasources"""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.CreatePXFDatasourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates PXF datasource"""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.UpdatePXFDatasourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update PXF datasource"""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.greenplum.v1.pxf_service_pb2.DeletePXFDatasourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete PXF datasource"""

def add_PXFDatasourceServiceServicer_to_server(servicer: PXFDatasourceServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/config.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/mdb/greenplum/v1/config.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"\x90\x02\n\x16\x43onnectionPoolerConfig\x12L\n\x04mode\x18\x01 \x01(\x0e\x32>.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig.PoolMode\x12)\n\x04size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x38\n\x13\x63lient_idle_timeout\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"C\n\x08PoolMode\x12\x19\n\x15POOL_MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07SESSION\x10\x01\x12\x0f\n\x0bTRANSACTION\x10\x02\"O\n\x19\x42\x61\x63kgroundActivityStartAt\x12\x17\n\x05hours\x18\x01 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-23\x12\x19\n\x07minutes\x18\x02 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-59\"_\n\nTableSizes\x12Q\n\x06starts\x18\x01 \x03(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.BackgroundActivityStartAtB\x07\x82\xc8\x31\x03<=4\"\xe6\x01\n\x10\x41nalyzeAndVacuum\x12G\n\x05start\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.BackgroundActivityStartAt\x12\x44\n\x0f\x61nalyze_timeout\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n7200-86399\x12\x43\n\x0evacuum_timeout\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n7200-86399\"\xfa\x01\n\x1a\x42\x61\x63kgroundActivitiesConfig\x12>\n\x0btable_sizes\x18\x01 \x01(\x0b\x32).yandex.cloud.mdb.greenplum.v1.TableSizes\x12K\n\x12\x61nalyze_and_vacuum\x18\x02 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.AnalyzeAndVacuum\x12O\n\x14query_killer_scripts\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.mdb.greenplum.v1.QueryKillerScripts\"\x8a\x01\n\x0bQueryKiller\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x07max_age\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x31-86400\x12\x14\n\x0cignore_users\x18\x03 \x03(\t\"\xd9\x01\n\x12QueryKillerScripts\x12\x38\n\x04idle\x18\x01 \x01(\x0b\x32*.yandex.cloud.mdb.greenplum.v1.QueryKiller\x12G\n\x13idle_in_transaction\x18\x02 \x01(\x0b\x32*.yandex.cloud.mdb.greenplum.v1.QueryKiller\x12@\n\x0clong_running\x18\x03 \x01(\x0b\x32*.yandex.cloud.mdb.greenplum.v1.QueryKiller\"U\n\x16MasterSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\"V\n\x17SegmentSubclusterConfig\x12;\n\tresources\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.Resources\"\xa7\x06\n\x10GreenplumConfig6\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x11max_statement_mem\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\rlog_statement\x18\t \x01(\x0e\x32+.yandex.cloud.mdb.greenplum.v1.LogStatement\x12H\n$gp_add_column_inherits_table_setting\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x46\n\"gp_enable_global_deadlock_detector\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12G\n\"gp_global_deadlock_detector_period\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xd3\x03\n\x13GreenplumConfig6_17\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xcf\x04\n\x13GreenplumConfig6_19\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x11max_statement_mem\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\rlog_statement\x18\t \x01(\x0e\x32+.yandex.cloud.mdb.greenplum.v1.LogStatement\"\x99\x05\n\x13GreenplumConfig6_21\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x11max_statement_mem\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\rlog_statement\x18\t \x01(\x0e\x32+.yandex.cloud.mdb.greenplum.v1.LogStatement\x12H\n$gp_add_column_inherits_table_setting\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x99\x05\n\x13GreenplumConfig6_22\x12\x34\n\x0fmax_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16max_slot_wal_keep_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\x1dgp_workfile_limit_per_segment\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1bgp_workfile_limit_per_query\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!gp_workfile_limit_files_per_query\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19max_prepared_transactions\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x17gp_workfile_compression\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x11max_statement_mem\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\rlog_statement\x18\t \x01(\x0e\x32+.yandex.cloud.mdb.greenplum.v1.LogStatement\x12H\n$gp_add_column_inherits_table_setting\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x81\x02\n\x16GreenplumConfigSet6_17\x12R\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17B\x04\xe8\xc7\x31\x01\x12G\n\x0buser_config\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17\x12J\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_17\"\x81\x02\n\x16GreenplumConfigSet6_19\x12R\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19B\x04\xe8\xc7\x31\x01\x12G\n\x0buser_config\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19\x12J\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_19\"\x81\x02\n\x16GreenplumConfigSet6_21\x12R\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_21B\x04\xe8\xc7\x31\x01\x12G\n\x0buser_config\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_21\x12J\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_21\"\x81\x02\n\x16GreenplumConfigSet6_22\x12R\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_22B\x04\xe8\xc7\x31\x01\x12G\n\x0buser_config\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_22\x12J\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6_22\"\xf5\x01\n\x13GreenplumConfigSet6\x12O\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6B\x04\xe8\xc7\x31\x01\x12\x44\n\x0buser_config\x18\x02 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6\x12G\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32/.yandex.cloud.mdb.greenplum.v1.GreenplumConfig6\"\x8d\x02\n\x19\x43onnectionPoolerConfigSet\x12U\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfigB\x04\xe8\xc7\x31\x01\x12J\n\x0buser_config\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig\x12M\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.mdb.greenplum.v1.ConnectionPoolerConfig*R\n\x0cLogStatement\x12\x1d\n\x19LOG_STATEMENT_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x07\n\x03\x44\x44L\x10\x02\x12\x07\n\x03MOD\x10\x03\x12\x07\n\x03\x41LL\x10\x04\x42p\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_BACKGROUNDACTIVITYSTARTAT'].fields_by_name['hours']._loaded_options = None
  _globals['_BACKGROUNDACTIVITYSTARTAT'].fields_by_name['hours']._serialized_options = b'\372\3071\0040-23'
  _globals['_BACKGROUNDACTIVITYSTARTAT'].fields_by_name['minutes']._loaded_options = None
  _globals['_BACKGROUNDACTIVITYSTARTAT'].fields_by_name['minutes']._serialized_options = b'\372\3071\0040-59'
  _globals['_TABLESIZES'].fields_by_name['starts']._loaded_options = None
  _globals['_TABLESIZES'].fields_by_name['starts']._serialized_options = b'\202\3101\003<=4'
  _globals['_ANALYZEANDVACUUM'].fields_by_name['analyze_timeout']._loaded_options = None
  _globals['_ANALYZEANDVACUUM'].fields_by_name['analyze_timeout']._serialized_options = b'\372\3071\n7200-86399'
  _globals['_ANALYZEANDVACUUM'].fields_by_name['vacuum_timeout']._loaded_options = None
  _globals['_ANALYZEANDVACUUM'].fields_by_name['vacuum_timeout']._serialized_options = b'\372\3071\n7200-86399'
  _globals['_QUERYKILLER'].fields_by_name['max_age']._loaded_options = None
  _globals['_QUERYKILLER'].fields_by_name['max_age']._serialized_options = b'\372\3071\0071-86400'
  _globals['_GREENPLUMCONFIGSET6_17'].fields_by_name['effective_config']._loaded_options = None
  _globals['_GREENPLUMCONFIGSET6_17'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_GREENPLUMCONFIGSET6_19'].fields_by_name['effective_config']._loaded_options = None
  _globals['_GREENPLUMCONFIGSET6_19'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_GREENPLUMCONFIGSET6_21'].fields_by_name['effective_config']._loaded_options = None
  _globals['_GREENPLUMCONFIGSET6_21'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_GREENPLUMCONFIGSET6_22'].fields_by_name['effective_config']._loaded_options = None
  _globals['_GREENPLUMCONFIGSET6_22'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_GREENPLUMCONFIGSET6'].fields_by_name['effective_config']._loaded_options = None
  _globals['_GREENPLUMCONFIGSET6'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_CONNECTIONPOOLERCONFIGSET'].fields_by_name['effective_config']._loaded_options = None
  _globals['_CONNECTIONPOOLERCONFIGSET'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_LOGSTATEMENT']._serialized_start=6467
  _globals['_LOGSTATEMENT']._serialized_end=6549
  _globals['_RESOURCES']._serialized_start=140
  _globals['_RESOURCES']._serialized_end=220
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_start=223
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_end=495
  _globals['_CONNECTIONPOOLERCONFIG_POOLMODE']._serialized_start=428
  _globals['_CONNECTIONPOOLERCONFIG_POOLMODE']._serialized_end=495
  _globals['_BACKGROUNDACTIVITYSTARTAT']._serialized_start=497
  _globals['_BACKGROUNDACTIVITYSTARTAT']._serialized_end=576
  _globals['_TABLESIZES']._serialized_start=578
  _globals['_TABLESIZES']._serialized_end=673
  _globals['_ANALYZEANDVACUUM']._serialized_start=676
  _globals['_ANALYZEANDVACUUM']._serialized_end=906
  _globals['_BACKGROUNDACTIVITIESCONFIG']._serialized_start=909
  _globals['_BACKGROUNDACTIVITIESCONFIG']._serialized_end=1159
  _globals['_QUERYKILLER']._serialized_start=1162
  _globals['_QUERYKILLER']._serialized_end=1300
  _globals['_QUERYKILLERSCRIPTS']._serialized_start=1303
  _globals['_QUERYKILLERSCRIPTS']._serialized_end=1520
  _globals['_MASTERSUBCLUSTERCONFIG']._serialized_start=1522
  _globals['_MASTERSUBCLUSTERCONFIG']._serialized_end=1607
  _globals['_SEGMENTSUBCLUSTERCONFIG']._serialized_start=1609
  _globals['_SEGMENTSUBCLUSTERCONFIG']._serialized_end=1695
  _globals['_GREENPLUMCONFIG6']._serialized_start=1698
  _globals['_GREENPLUMCONFIG6']._serialized_end=2505
  _globals['_GREENPLUMCONFIG6_17']._serialized_start=2508
  _globals['_GREENPLUMCONFIG6_17']._serialized_end=2975
  _globals['_GREENPLUMCONFIG6_19']._serialized_start=2978
  _globals['_GREENPLUMCONFIG6_19']._serialized_end=3569
  _globals['_GREENPLUMCONFIG6_21']._serialized_start=3572
  _globals['_GREENPLUMCONFIG6_21']._serialized_end=4237
  _globals['_GREENPLUMCONFIG6_22']._serialized_start=4240
  _globals['_GREENPLUMCONFIG6_22']._serialized_end=4905
  _globals['_GREENPLUMCONFIGSET6_17']._serialized_start=4908
  _globals['_GREENPLUMCONFIGSET6_17']._serialized_end=5165
  _globals['_GREENPLUMCONFIGSET6_19']._serialized_start=5168
  _globals['_GREENPLUMCONFIGSET6_19']._serialized_end=5425
  _globals['_GREENPLUMCONFIGSET6_21']._serialized_start=5428
  _globals['_GREENPLUMCONFIGSET6_21']._serialized_end=5685
  _globals['_GREENPLUMCONFIGSET6_22']._serialized_start=5688
  _globals['_GREENPLUMCONFIGSET6_22']._serialized_end=5945
  _globals['_GREENPLUMCONFIGSET6']._serialized_start=5948
  _globals['_GREENPLUMCONFIGSET6']._serialized_end=6193
  _globals['_CONNECTIONPOOLERCONFIGSET']._serialized_start=6196
  _globals['_CONNECTIONPOOLERCONFIGSET']._serialized_end=6465
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OptimizerAdamw(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BETA1_FIELD_NUMBER: builtins.int
    BETA2_FIELD_NUMBER: builtins.int
    EPS_FIELD_NUMBER: builtins.int
    WEIGHT_DECAY_FIELD_NUMBER: builtins.int
    beta1: builtins.float
    beta2: builtins.float
    eps: builtins.float
    weight_decay: builtins.float
    def __init__(
        self,
        *,
        beta1: builtins.float = ...,
        beta2: builtins.float = ...,
        eps: builtins.float = ...,
        weight_decay: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["beta1", b"beta1", "beta2", b"beta2", "eps", b"eps", "weight_decay", b"weight_decay"]) -> None: ...

global___OptimizerAdamw = OptimizerAdamw



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/licensemanager/v1/lock.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/licensemanager/v1/lock.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/marketplace/licensemanager/v1/lock.proto\x12*yandex.cloud.marketplace.licensemanager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9d\x03\n\x04Lock\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0binstance_id\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x45\n\x05state\x18\x08 \x01(\x0e\x32\x36.yandex.cloud.marketplace.licensemanager.v1.Lock.State\x12\x13\n\x0btemplate_id\x18\t \x01(\t\"E\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08UNLOCKED\x10\x01\x12\n\n\x06LOCKED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\x42\x8f\x01\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.licensemanager.v1.lock_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanager'
  _globals['_LOCK']._serialized_start=135
  _globals['_LOCK']._serialized_end=548
  _globals['_LOCK_STATE']._serialized_start=479
  _globals['_LOCK_STATE']._serialized_end=548
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.compute.v1.image_pb2
import yandex.cloud.compute.v1.image_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ImageServiceStub:
    """A set of methods for managing Image resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.GetImageRequest,
        yandex.cloud.compute.v1.image_pb2.Image,
    ]
    """Returns the specified Image resource.

    To get the list of available Image resources, make a [List] request.
    """

    GetLatestByFamily: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.GetImageLatestByFamilyRequest,
        yandex.cloud.compute.v1.image_pb2.Image,
    ]
    """Returns the latest image that is part of an image family."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.ListImagesRequest,
        yandex.cloud.compute.v1.image_service_pb2.ListImagesResponse,
    ]
    """Retrieves the list of Image resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.CreateImageRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an image in the specified folder.

    You can create an image from a disk, snapshot, other image or URI.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.UpdateImageRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified image."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.DeleteImageRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified image.

    Deleting an image removes its data permanently and is irreversible.
    """

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.ListImageOperationsRequest,
        yandex.cloud.compute.v1.image_service_pb2.ListImageOperationsResponse,
    ]
    """Lists operations for the specified image."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the image.
    """

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the image."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the image."""

class ImageServiceAsyncStub:
    """A set of methods for managing Image resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.GetImageRequest,
        yandex.cloud.compute.v1.image_pb2.Image,
    ]
    """Returns the specified Image resource.

    To get the list of available Image resources, make a [List] request.
    """

    GetLatestByFamily: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.GetImageLatestByFamilyRequest,
        yandex.cloud.compute.v1.image_pb2.Image,
    ]
    """Returns the latest image that is part of an image family."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.ListImagesRequest,
        yandex.cloud.compute.v1.image_service_pb2.ListImagesResponse,
    ]
    """Retrieves the list of Image resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.CreateImageRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an image in the specified folder.

    You can create an image from a disk, snapshot, other image or URI.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.UpdateImageRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified image."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.DeleteImageRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified image.

    Deleting an image removes its data permanently and is irreversible.
    """

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.image_service_pb2.ListImageOperationsRequest,
        yandex.cloud.compute.v1.image_service_pb2.ListImageOperationsResponse,
    ]
    """Lists operations for the specified image."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the image.
    """

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the image."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the image."""

class ImageServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Image resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.compute.v1.image_service_pb2.GetImageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.image_pb2.Image, collections.abc.Awaitable[yandex.cloud.compute.v1.image_pb2.Image]]:
        """Returns the specified Image resource.

        To get the list of available Image resources, make a [List] request.
        """

    @abc.abstractmethod
    def GetLatestByFamily(
        self,
        request: yandex.cloud.compute.v1.image_service_pb2.GetImageLatestByFamilyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.image_pb2.Image, collections.abc.Awaitable[yandex.cloud.compute.v1.image_pb2.Image]]:
        """Returns the latest image that is part of an image family."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.compute.v1.image_service_pb2.ListImagesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.image_service_pb2.ListImagesResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.image_service_pb2.ListImagesResponse]]:
        """Retrieves the list of Image resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.compute.v1.image_service_pb2.CreateImageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an image in the specified folder.

        You can create an image from a disk, snapshot, other image or URI.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.compute.v1.image_service_pb2.UpdateImageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified image."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.compute.v1.image_service_pb2.DeleteImageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified image.

        Deleting an image removes its data permanently and is irreversible.
        """

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.compute.v1.image_service_pb2.ListImageOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.image_service_pb2.ListImageOperationsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.image_service_pb2.ListImageOperationsResponse]]:
        """Lists operations for the specified image."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the image.
        """

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the image."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the image."""

def add_ImageServiceServicer_to_server(servicer: ImageServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cic/v1/partner_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cic/v1/partner_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.cic.v1 import partner_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_partner__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/cic/v1/partner_service.proto\x12\x13yandex.cloud.cic.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a!yandex/cloud/cic/v1/partner.proto\"5\n\x11GetPartnerRequest\x12 \n\npartner_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"u\n\x13ListPartnersRequest\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x01\x10\x02\"_\n\x14ListPartnersResponse\x12.\n\x08partners\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.cic.v1.Partner\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xfb\x01\n\x0ePartnerService\x12r\n\x03Get\x12&.yandex.cloud.cic.v1.GetPartnerRequest\x1a\x1c.yandex.cloud.cic.v1.Partner\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cic/v1/partners/{partner_id}\x12u\n\x04List\x12(.yandex.cloud.cic.v1.ListPartnersRequest\x1a).yandex.cloud.cic.v1.ListPartnersResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/cic/v1/partnersBV\n\x17yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.partner_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cic'
  _globals['_GETPARTNERREQUEST'].fields_by_name['partner_id']._loaded_options = None
  _globals['_GETPARTNERREQUEST'].fields_by_name['partner_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTPARTNERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPARTNERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTPARTNERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTPARTNERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTPARTNERSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTPARTNERSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PARTNERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_PARTNERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\037\022\035/cic/v1/partners/{partner_id}'
  _globals['_PARTNERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_PARTNERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\022\022\020/cic/v1/partners'
  _globals['_GETPARTNERREQUEST']._serialized_start=162
  _globals['_GETPARTNERREQUEST']._serialized_end=215
  _globals['_LISTPARTNERSREQUEST']._serialized_start=217
  _globals['_LISTPARTNERSREQUEST']._serialized_end=334
  _globals['_LISTPARTNERSRESPONSE']._serialized_start=336
  _globals['_LISTPARTNERSRESPONSE']._serialized_end=431
  _globals['_PARTNERSERVICE']._serialized_start=434
  _globals['_PARTNERSERVICE']._serialized_end=685
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.spqr.v1.cluster_pb2
import yandex.cloud.mdb.spqr.v1.cluster_service_pb2
import yandex.cloud.mdb.spqr.v1.shard_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ClusterServiceStub:
    """A set of methods for managing SPQR Cluster resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.GetClusterRequest,
        yandex.cloud.mdb.spqr.v1.cluster_pb2.Cluster,
    ]
    """Returns the specified SPQR Cluster resource.

    To get the list of available SPQR Cluster resources, make a [List] request.
    """

    GetAtRevision: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.GetClusterAtRevisionRequest,
        yandex.cloud.mdb.spqr.v1.cluster_pb2.Cluster,
    ]

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClustersRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClustersResponse,
    ]
    """Retrieves the list of SPQR Cluster resources that belong
    to the specified folder.
    """

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.CreateClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a SPQR cluster in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.UpdateClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified SPQR cluster."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.DeleteClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified SPQR cluster."""

    AddSubcluster: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.AddSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    Start: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.StartClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Start the specified SPQR cluster."""

    Stop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.StopClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stop the specified SPQR cluster."""

    Move: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.MoveClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified SPQR cluster to the specified folder."""

    Backup: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.BackupClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a backup for the specified SPQR cluster."""

    Restore: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.RestoreClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new SPQR cluster using the specified backup."""

    RescheduleMaintenance: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.RescheduleMaintenanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reschedules planned maintenance operation."""

    ListLogs: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterLogsRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterLogsResponse,
    ]
    """Retrieves logs for the specified SPQR cluster.
    See the [Logs](/yandex-mdb-guide/concepts/logs.html) section in the developers guide for detailed logs description.
    """

    StreamLogs: grpc.UnaryStreamMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.StreamClusterLogsRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.StreamLogRecord,
    ]
    """Same as ListLogs but using server-side streaming. Also allows for 'tail -f' semantics."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterOperationsRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterOperationsResponse,
    ]
    """Retrieves the list of Operation resources for the specified cluster."""

    ListBackups: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterBackupsRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterBackupsResponse,
    ]
    """Retrieves the list of available backups for the specified SPQR cluster."""

    ListHosts: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsResponse,
    ]
    """Retrieves a list of hosts for the specified cluster."""

    ListHostsAtRevision: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsAtRevisionRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsResponse,
    ]
    """Retrieves a list of hosts for the specified cluster."""

    AddHosts: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.AddClusterHostsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates new hosts for a cluster."""

    DeleteHosts: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.DeleteClusterHostsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified hosts for a cluster."""

    ResetupHosts: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ResetupHostsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Resetups hosts."""

    GetShard: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.GetClusterShardRequest,
        yandex.cloud.mdb.spqr.v1.shard_pb2.Shard,
    ]
    """Returns the specified shard."""

    ListShards: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsResponse,
    ]
    """Retrieves a list of shards."""

    ListShardsAtRevision: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsAtRevisionRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsResponse,
    ]
    """Retrieves a list of shards."""

    AddShard: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.AddClusterShardRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new shard."""

    DeleteShard: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.DeleteClusterShardRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified shard."""

class ClusterServiceAsyncStub:
    """A set of methods for managing SPQR Cluster resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.GetClusterRequest,
        yandex.cloud.mdb.spqr.v1.cluster_pb2.Cluster,
    ]
    """Returns the specified SPQR Cluster resource.

    To get the list of available SPQR Cluster resources, make a [List] request.
    """

    GetAtRevision: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.GetClusterAtRevisionRequest,
        yandex.cloud.mdb.spqr.v1.cluster_pb2.Cluster,
    ]

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClustersRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClustersResponse,
    ]
    """Retrieves the list of SPQR Cluster resources that belong
    to the specified folder.
    """

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.CreateClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a SPQR cluster in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.UpdateClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified SPQR cluster."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.DeleteClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified SPQR cluster."""

    AddSubcluster: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.AddSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]

    Start: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.StartClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Start the specified SPQR cluster."""

    Stop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.StopClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stop the specified SPQR cluster."""

    Move: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.MoveClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified SPQR cluster to the specified folder."""

    Backup: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.BackupClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a backup for the specified SPQR cluster."""

    Restore: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.RestoreClusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new SPQR cluster using the specified backup."""

    RescheduleMaintenance: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.RescheduleMaintenanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Reschedules planned maintenance operation."""

    ListLogs: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterLogsRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterLogsResponse,
    ]
    """Retrieves logs for the specified SPQR cluster.
    See the [Logs](/yandex-mdb-guide/concepts/logs.html) section in the developers guide for detailed logs description.
    """

    StreamLogs: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.StreamClusterLogsRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.StreamLogRecord,
    ]
    """Same as ListLogs but using server-side streaming. Also allows for 'tail -f' semantics."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterOperationsRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterOperationsResponse,
    ]
    """Retrieves the list of Operation resources for the specified cluster."""

    ListBackups: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterBackupsRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterBackupsResponse,
    ]
    """Retrieves the list of available backups for the specified SPQR cluster."""

    ListHosts: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsResponse,
    ]
    """Retrieves a list of hosts for the specified cluster."""

    ListHostsAtRevision: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsAtRevisionRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsResponse,
    ]
    """Retrieves a list of hosts for the specified cluster."""

    AddHosts: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.AddClusterHostsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates new hosts for a cluster."""

    DeleteHosts: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.DeleteClusterHostsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified hosts for a cluster."""

    ResetupHosts: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ResetupHostsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Resetups hosts."""

    GetShard: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.GetClusterShardRequest,
        yandex.cloud.mdb.spqr.v1.shard_pb2.Shard,
    ]
    """Returns the specified shard."""

    ListShards: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsResponse,
    ]
    """Retrieves a list of shards."""

    ListShardsAtRevision: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsAtRevisionRequest,
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsResponse,
    ]
    """Retrieves a list of shards."""

    AddShard: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.AddClusterShardRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new shard."""

    DeleteShard: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.spqr.v1.cluster_service_pb2.DeleteClusterShardRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified shard."""

class ClusterServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing SPQR Cluster resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.GetClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.spqr.v1.cluster_pb2.Cluster, collections.abc.Awaitable[yandex.cloud.mdb.spqr.v1.cluster_pb2.Cluster]]:
        """Returns the specified SPQR Cluster resource.

        To get the list of available SPQR Cluster resources, make a [List] request.
        """

    @abc.abstractmethod
    def GetAtRevision(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.GetClusterAtRevisionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.spqr.v1.cluster_pb2.Cluster, collections.abc.Awaitable[yandex.cloud.mdb.spqr.v1.cluster_pb2.Cluster]]: ...

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClustersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClustersResponse, collections.abc.Awaitable[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClustersResponse]]:
        """Retrieves the list of SPQR Cluster resources that belong
        to the specified folder.
        """

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.CreateClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a SPQR cluster in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.UpdateClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified SPQR cluster."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.DeleteClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified SPQR cluster."""

    @abc.abstractmethod
    def AddSubcluster(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.AddSubclusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]: ...

    @abc.abstractmethod
    def Start(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.StartClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Start the specified SPQR cluster."""

    @abc.abstractmethod
    def Stop(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.StopClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Stop the specified SPQR cluster."""

    @abc.abstractmethod
    def Move(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.MoveClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Moves the specified SPQR cluster to the specified folder."""

    @abc.abstractmethod
    def Backup(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.BackupClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a backup for the specified SPQR cluster."""

    @abc.abstractmethod
    def Restore(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.RestoreClusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new SPQR cluster using the specified backup."""

    @abc.abstractmethod
    def RescheduleMaintenance(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.RescheduleMaintenanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Reschedules planned maintenance operation."""

    @abc.abstractmethod
    def ListLogs(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterLogsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterLogsResponse, collections.abc.Awaitable[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterLogsResponse]]:
        """Retrieves logs for the specified SPQR cluster.
        See the [Logs](/yandex-mdb-guide/concepts/logs.html) section in the developers guide for detailed logs description.
        """

    @abc.abstractmethod
    def StreamLogs(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.StreamClusterLogsRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.StreamLogRecord], collections.abc.AsyncIterator[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.StreamLogRecord]]:
        """Same as ListLogs but using server-side streaming. Also allows for 'tail -f' semantics."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterOperationsResponse, collections.abc.Awaitable[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterOperationsResponse]]:
        """Retrieves the list of Operation resources for the specified cluster."""

    @abc.abstractmethod
    def ListBackups(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterBackupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterBackupsResponse, collections.abc.Awaitable[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterBackupsResponse]]:
        """Retrieves the list of available backups for the specified SPQR cluster."""

    @abc.abstractmethod
    def ListHosts(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsResponse, collections.abc.Awaitable[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsResponse]]:
        """Retrieves a list of hosts for the specified cluster."""

    @abc.abstractmethod
    def ListHostsAtRevision(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsAtRevisionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsResponse, collections.abc.Awaitable[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterHostsResponse]]:
        """Retrieves a list of hosts for the specified cluster."""

    @abc.abstractmethod
    def AddHosts(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.AddClusterHostsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates new hosts for a cluster."""

    @abc.abstractmethod
    def DeleteHosts(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.DeleteClusterHostsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified hosts for a cluster."""

    @abc.abstractmethod
    def ResetupHosts(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ResetupHostsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Resetups hosts."""

    @abc.abstractmethod
    def GetShard(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.GetClusterShardRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.spqr.v1.shard_pb2.Shard, collections.abc.Awaitable[yandex.cloud.mdb.spqr.v1.shard_pb2.Shard]]:
        """Returns the specified shard."""

    @abc.abstractmethod
    def ListShards(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsResponse, collections.abc.Awaitable[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsResponse]]:
        """Retrieves a list of shards."""

    @abc.abstractmethod
    def ListShardsAtRevision(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsAtRevisionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsResponse, collections.abc.Awaitable[yandex.cloud.mdb.spqr.v1.cluster_service_pb2.ListClusterShardsResponse]]:
        """Retrieves a list of shards."""

    @abc.abstractmethod
    def AddShard(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.AddClusterShardRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new shard."""

    @abc.abstractmethod
    def DeleteShard(
        self,
        request: yandex.cloud.mdb.spqr.v1.cluster_service_pb2.DeleteClusterShardRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified shard."""

def add_ClusterServiceServicer_to_server(servicer: ClusterServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
